# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DoArgs', 'Do']

@pulumi.input_type
class DoArgs:
    def __init__(__self__, *,
                 do_json: pulumi.Input[str],
                 bigip_address: Optional[pulumi.Input[str]] = None,
                 bigip_password: Optional[pulumi.Input[str]] = None,
                 bigip_port: Optional[pulumi.Input[str]] = None,
                 bigip_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigip_user: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 timeout: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Do resource.
        :param pulumi.Input[str] do_json: Name of the of the Declarative DO JSON file
        :param pulumi.Input[str] bigip_address: IP Address of BIGIP Host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] bigip_password: Password of BIGIP host to be used for this resource
        :param pulumi.Input[str] bigip_port: Port number of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[bool] bigip_token_auth: Enable to use an external authentication source (LDAP, TACACS, etc)
        :param pulumi.Input[str] bigip_user: UserName of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] tenant_name: unique identifier for DO resource
        :param pulumi.Input[int] timeout: DO json
        """
        pulumi.set(__self__, "do_json", do_json)
        if bigip_address is not None:
            pulumi.set(__self__, "bigip_address", bigip_address)
        if bigip_password is not None:
            pulumi.set(__self__, "bigip_password", bigip_password)
        if bigip_port is not None:
            pulumi.set(__self__, "bigip_port", bigip_port)
        if bigip_token_auth is not None:
            pulumi.set(__self__, "bigip_token_auth", bigip_token_auth)
        if bigip_user is not None:
            pulumi.set(__self__, "bigip_user", bigip_user)
        if tenant_name is not None:
            warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
            pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")
        if tenant_name is not None:
            pulumi.set(__self__, "tenant_name", tenant_name)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="doJson")
    def do_json(self) -> pulumi.Input[str]:
        """
        Name of the of the Declarative DO JSON file
        """
        return pulumi.get(self, "do_json")

    @do_json.setter
    def do_json(self, value: pulumi.Input[str]):
        pulumi.set(self, "do_json", value)

    @property
    @pulumi.getter(name="bigipAddress")
    def bigip_address(self) -> Optional[pulumi.Input[str]]:
        """
        IP Address of BIGIP Host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_address")

    @bigip_address.setter
    def bigip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_address", value)

    @property
    @pulumi.getter(name="bigipPassword")
    def bigip_password(self) -> Optional[pulumi.Input[str]]:
        """
        Password of BIGIP host to be used for this resource
        """
        return pulumi.get(self, "bigip_password")

    @bigip_password.setter
    def bigip_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_password", value)

    @property
    @pulumi.getter(name="bigipPort")
    def bigip_port(self) -> Optional[pulumi.Input[str]]:
        """
        Port number of BIGIP host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_port")

    @bigip_port.setter
    def bigip_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_port", value)

    @property
    @pulumi.getter(name="bigipTokenAuth")
    def bigip_token_auth(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable to use an external authentication source (LDAP, TACACS, etc)
        """
        return pulumi.get(self, "bigip_token_auth")

    @bigip_token_auth.setter
    def bigip_token_auth(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "bigip_token_auth", value)

    @property
    @pulumi.getter(name="bigipUser")
    def bigip_user(self) -> Optional[pulumi.Input[str]]:
        """
        UserName of BIGIP host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_user")

    @bigip_user.setter
    def bigip_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_user", value)

    @property
    @pulumi.getter(name="tenantName")
    @_utilities.deprecated("""this attribute is no longer in use""")
    def tenant_name(self) -> Optional[pulumi.Input[str]]:
        """
        unique identifier for DO resource
        """
        return pulumi.get(self, "tenant_name")

    @tenant_name.setter
    def tenant_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_name", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[int]]:
        """
        DO json
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _DoState:
    def __init__(__self__, *,
                 bigip_address: Optional[pulumi.Input[str]] = None,
                 bigip_password: Optional[pulumi.Input[str]] = None,
                 bigip_port: Optional[pulumi.Input[str]] = None,
                 bigip_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigip_user: Optional[pulumi.Input[str]] = None,
                 do_json: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 timeout: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Do resources.
        :param pulumi.Input[str] bigip_address: IP Address of BIGIP Host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] bigip_password: Password of BIGIP host to be used for this resource
        :param pulumi.Input[str] bigip_port: Port number of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[bool] bigip_token_auth: Enable to use an external authentication source (LDAP, TACACS, etc)
        :param pulumi.Input[str] bigip_user: UserName of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] do_json: Name of the of the Declarative DO JSON file
        :param pulumi.Input[str] tenant_name: unique identifier for DO resource
        :param pulumi.Input[int] timeout: DO json
        """
        if bigip_address is not None:
            pulumi.set(__self__, "bigip_address", bigip_address)
        if bigip_password is not None:
            pulumi.set(__self__, "bigip_password", bigip_password)
        if bigip_port is not None:
            pulumi.set(__self__, "bigip_port", bigip_port)
        if bigip_token_auth is not None:
            pulumi.set(__self__, "bigip_token_auth", bigip_token_auth)
        if bigip_user is not None:
            pulumi.set(__self__, "bigip_user", bigip_user)
        if do_json is not None:
            pulumi.set(__self__, "do_json", do_json)
        if tenant_name is not None:
            warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
            pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")
        if tenant_name is not None:
            pulumi.set(__self__, "tenant_name", tenant_name)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="bigipAddress")
    def bigip_address(self) -> Optional[pulumi.Input[str]]:
        """
        IP Address of BIGIP Host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_address")

    @bigip_address.setter
    def bigip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_address", value)

    @property
    @pulumi.getter(name="bigipPassword")
    def bigip_password(self) -> Optional[pulumi.Input[str]]:
        """
        Password of BIGIP host to be used for this resource
        """
        return pulumi.get(self, "bigip_password")

    @bigip_password.setter
    def bigip_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_password", value)

    @property
    @pulumi.getter(name="bigipPort")
    def bigip_port(self) -> Optional[pulumi.Input[str]]:
        """
        Port number of BIGIP host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_port")

    @bigip_port.setter
    def bigip_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_port", value)

    @property
    @pulumi.getter(name="bigipTokenAuth")
    def bigip_token_auth(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable to use an external authentication source (LDAP, TACACS, etc)
        """
        return pulumi.get(self, "bigip_token_auth")

    @bigip_token_auth.setter
    def bigip_token_auth(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "bigip_token_auth", value)

    @property
    @pulumi.getter(name="bigipUser")
    def bigip_user(self) -> Optional[pulumi.Input[str]]:
        """
        UserName of BIGIP host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_user")

    @bigip_user.setter
    def bigip_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigip_user", value)

    @property
    @pulumi.getter(name="doJson")
    def do_json(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the of the Declarative DO JSON file
        """
        return pulumi.get(self, "do_json")

    @do_json.setter
    def do_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "do_json", value)

    @property
    @pulumi.getter(name="tenantName")
    @_utilities.deprecated("""this attribute is no longer in use""")
    def tenant_name(self) -> Optional[pulumi.Input[str]]:
        """
        unique identifier for DO resource
        """
        return pulumi.get(self, "tenant_name")

    @tenant_name.setter
    def tenant_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_name", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[int]]:
        """
        DO json
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout", value)


class Do(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bigip_address: Optional[pulumi.Input[str]] = None,
                 bigip_password: Optional[pulumi.Input[str]] = None,
                 bigip_port: Optional[pulumi.Input[str]] = None,
                 bigip_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigip_user: Optional[pulumi.Input[str]] = None,
                 do_json: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 timeout: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Create a Do resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bigip_address: IP Address of BIGIP Host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] bigip_password: Password of BIGIP host to be used for this resource
        :param pulumi.Input[str] bigip_port: Port number of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[bool] bigip_token_auth: Enable to use an external authentication source (LDAP, TACACS, etc)
        :param pulumi.Input[str] bigip_user: UserName of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] do_json: Name of the of the Declarative DO JSON file
        :param pulumi.Input[str] tenant_name: unique identifier for DO resource
        :param pulumi.Input[int] timeout: DO json
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DoArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Do resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param DoArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DoArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bigip_address: Optional[pulumi.Input[str]] = None,
                 bigip_password: Optional[pulumi.Input[str]] = None,
                 bigip_port: Optional[pulumi.Input[str]] = None,
                 bigip_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigip_user: Optional[pulumi.Input[str]] = None,
                 do_json: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 timeout: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DoArgs.__new__(DoArgs)

            __props__.__dict__["bigip_address"] = bigip_address
            __props__.__dict__["bigip_password"] = None if bigip_password is None else pulumi.Output.secret(bigip_password)
            __props__.__dict__["bigip_port"] = bigip_port
            __props__.__dict__["bigip_token_auth"] = None if bigip_token_auth is None else pulumi.Output.secret(bigip_token_auth)
            __props__.__dict__["bigip_user"] = bigip_user
            if do_json is None and not opts.urn:
                raise TypeError("Missing required property 'do_json'")
            __props__.__dict__["do_json"] = do_json
            __props__.__dict__["tenant_name"] = tenant_name
            __props__.__dict__["timeout"] = timeout
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["bigipPassword", "bigipTokenAuth"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Do, __self__).__init__(
            'f5bigip:index/do:Do',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bigip_address: Optional[pulumi.Input[str]] = None,
            bigip_password: Optional[pulumi.Input[str]] = None,
            bigip_port: Optional[pulumi.Input[str]] = None,
            bigip_token_auth: Optional[pulumi.Input[bool]] = None,
            bigip_user: Optional[pulumi.Input[str]] = None,
            do_json: Optional[pulumi.Input[str]] = None,
            tenant_name: Optional[pulumi.Input[str]] = None,
            timeout: Optional[pulumi.Input[int]] = None) -> 'Do':
        """
        Get an existing Do resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bigip_address: IP Address of BIGIP Host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] bigip_password: Password of BIGIP host to be used for this resource
        :param pulumi.Input[str] bigip_port: Port number of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[bool] bigip_token_auth: Enable to use an external authentication source (LDAP, TACACS, etc)
        :param pulumi.Input[str] bigip_user: UserName of BIGIP host to be used for this resource,this is optional parameter.
               whenever we specify this parameter it gets overwrite provider configuration
        :param pulumi.Input[str] do_json: Name of the of the Declarative DO JSON file
        :param pulumi.Input[str] tenant_name: unique identifier for DO resource
        :param pulumi.Input[int] timeout: DO json
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DoState.__new__(_DoState)

        __props__.__dict__["bigip_address"] = bigip_address
        __props__.__dict__["bigip_password"] = bigip_password
        __props__.__dict__["bigip_port"] = bigip_port
        __props__.__dict__["bigip_token_auth"] = bigip_token_auth
        __props__.__dict__["bigip_user"] = bigip_user
        __props__.__dict__["do_json"] = do_json
        __props__.__dict__["tenant_name"] = tenant_name
        __props__.__dict__["timeout"] = timeout
        return Do(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bigipAddress")
    def bigip_address(self) -> pulumi.Output[Optional[str]]:
        """
        IP Address of BIGIP Host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_address")

    @property
    @pulumi.getter(name="bigipPassword")
    def bigip_password(self) -> pulumi.Output[Optional[str]]:
        """
        Password of BIGIP host to be used for this resource
        """
        return pulumi.get(self, "bigip_password")

    @property
    @pulumi.getter(name="bigipPort")
    def bigip_port(self) -> pulumi.Output[Optional[str]]:
        """
        Port number of BIGIP host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_port")

    @property
    @pulumi.getter(name="bigipTokenAuth")
    def bigip_token_auth(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable to use an external authentication source (LDAP, TACACS, etc)
        """
        return pulumi.get(self, "bigip_token_auth")

    @property
    @pulumi.getter(name="bigipUser")
    def bigip_user(self) -> pulumi.Output[Optional[str]]:
        """
        UserName of BIGIP host to be used for this resource,this is optional parameter.
        whenever we specify this parameter it gets overwrite provider configuration
        """
        return pulumi.get(self, "bigip_user")

    @property
    @pulumi.getter(name="doJson")
    def do_json(self) -> pulumi.Output[str]:
        """
        Name of the of the Declarative DO JSON file
        """
        return pulumi.get(self, "do_json")

    @property
    @pulumi.getter(name="tenantName")
    @_utilities.deprecated("""this attribute is no longer in use""")
    def tenant_name(self) -> pulumi.Output[Optional[str]]:
        """
        unique identifier for DO resource
        """
        return pulumi.get(self, "tenant_name")

    @property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[Optional[int]]:
        """
        DO json
        """
        return pulumi.get(self, "timeout")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProfileWebAccelerationArgs', 'ProfileWebAcceleration']

@pulumi.input_type
class ProfileWebAccelerationArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 cache_aging_rate: Optional[pulumi.Input[int]] = None,
                 cache_client_cache_control_mode: Optional[pulumi.Input[str]] = None,
                 cache_insert_age_header: Optional[pulumi.Input[str]] = None,
                 cache_max_age: Optional[pulumi.Input[int]] = None,
                 cache_max_entries: Optional[pulumi.Input[int]] = None,
                 cache_object_max_size: Optional[pulumi.Input[int]] = None,
                 cache_object_min_size: Optional[pulumi.Input[int]] = None,
                 cache_size: Optional[pulumi.Input[int]] = None,
                 cache_uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_include_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_pinneds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProfileWebAcceleration resource.
        :param pulumi.Input[str] name: Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        :param pulumi.Input[int] cache_aging_rate: Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        :param pulumi.Input[str] cache_client_cache_control_mode: Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        :param pulumi.Input[str] cache_insert_age_header: Inserts Age and Date headers in the response. The default value is `enabled`.
        :param pulumi.Input[int] cache_max_age: Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        :param pulumi.Input[int] cache_max_entries: Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        :param pulumi.Input[int] cache_object_max_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_object_min_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_size: Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_excludes: Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_include_overrides: Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_includes: Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_pinneds: Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        pulumi.set(__self__, "name", name)
        if cache_aging_rate is not None:
            pulumi.set(__self__, "cache_aging_rate", cache_aging_rate)
        if cache_client_cache_control_mode is not None:
            pulumi.set(__self__, "cache_client_cache_control_mode", cache_client_cache_control_mode)
        if cache_insert_age_header is not None:
            pulumi.set(__self__, "cache_insert_age_header", cache_insert_age_header)
        if cache_max_age is not None:
            pulumi.set(__self__, "cache_max_age", cache_max_age)
        if cache_max_entries is not None:
            pulumi.set(__self__, "cache_max_entries", cache_max_entries)
        if cache_object_max_size is not None:
            pulumi.set(__self__, "cache_object_max_size", cache_object_max_size)
        if cache_object_min_size is not None:
            pulumi.set(__self__, "cache_object_min_size", cache_object_min_size)
        if cache_size is not None:
            pulumi.set(__self__, "cache_size", cache_size)
        if cache_uri_excludes is not None:
            pulumi.set(__self__, "cache_uri_excludes", cache_uri_excludes)
        if cache_uri_include_overrides is not None:
            pulumi.set(__self__, "cache_uri_include_overrides", cache_uri_include_overrides)
        if cache_uri_includes is not None:
            pulumi.set(__self__, "cache_uri_includes", cache_uri_includes)
        if cache_uri_pinneds is not None:
            pulumi.set(__self__, "cache_uri_pinneds", cache_uri_pinneds)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="cacheAgingRate")
    def cache_aging_rate(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        """
        return pulumi.get(self, "cache_aging_rate")

    @cache_aging_rate.setter
    def cache_aging_rate(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_aging_rate", value)

    @property
    @pulumi.getter(name="cacheClientCacheControlMode")
    def cache_client_cache_control_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        """
        return pulumi.get(self, "cache_client_cache_control_mode")

    @cache_client_cache_control_mode.setter
    def cache_client_cache_control_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cache_client_cache_control_mode", value)

    @property
    @pulumi.getter(name="cacheInsertAgeHeader")
    def cache_insert_age_header(self) -> Optional[pulumi.Input[str]]:
        """
        Inserts Age and Date headers in the response. The default value is `enabled`.
        """
        return pulumi.get(self, "cache_insert_age_header")

    @cache_insert_age_header.setter
    def cache_insert_age_header(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cache_insert_age_header", value)

    @property
    @pulumi.getter(name="cacheMaxAge")
    def cache_max_age(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        """
        return pulumi.get(self, "cache_max_age")

    @cache_max_age.setter
    def cache_max_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_max_age", value)

    @property
    @pulumi.getter(name="cacheMaxEntries")
    def cache_max_entries(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        """
        return pulumi.get(self, "cache_max_entries")

    @cache_max_entries.setter
    def cache_max_entries(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_max_entries", value)

    @property
    @pulumi.getter(name="cacheObjectMaxSize")
    def cache_object_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        """
        return pulumi.get(self, "cache_object_max_size")

    @cache_object_max_size.setter
    def cache_object_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_object_max_size", value)

    @property
    @pulumi.getter(name="cacheObjectMinSize")
    def cache_object_min_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        """
        return pulumi.get(self, "cache_object_min_size")

    @cache_object_min_size.setter
    def cache_object_min_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_object_min_size", value)

    @property
    @pulumi.getter(name="cacheSize")
    def cache_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        """
        return pulumi.get(self, "cache_size")

    @cache_size.setter
    def cache_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_size", value)

    @property
    @pulumi.getter(name="cacheUriExcludes")
    def cache_uri_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        """
        return pulumi.get(self, "cache_uri_excludes")

    @cache_uri_excludes.setter
    def cache_uri_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_excludes", value)

    @property
    @pulumi.getter(name="cacheUriIncludeOverrides")
    def cache_uri_include_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        """
        return pulumi.get(self, "cache_uri_include_overrides")

    @cache_uri_include_overrides.setter
    def cache_uri_include_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_include_overrides", value)

    @property
    @pulumi.getter(name="cacheUriIncludes")
    def cache_uri_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        """
        return pulumi.get(self, "cache_uri_includes")

    @cache_uri_includes.setter
    def cache_uri_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_includes", value)

    @property
    @pulumi.getter(name="cacheUriPinneds")
    def cache_uri_pinneds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        """
        return pulumi.get(self, "cache_uri_pinneds")

    @cache_uri_pinneds.setter
    def cache_uri_pinneds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_pinneds", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)


@pulumi.input_type
class _ProfileWebAccelerationState:
    def __init__(__self__, *,
                 cache_aging_rate: Optional[pulumi.Input[int]] = None,
                 cache_client_cache_control_mode: Optional[pulumi.Input[str]] = None,
                 cache_insert_age_header: Optional[pulumi.Input[str]] = None,
                 cache_max_age: Optional[pulumi.Input[int]] = None,
                 cache_max_entries: Optional[pulumi.Input[int]] = None,
                 cache_object_max_size: Optional[pulumi.Input[int]] = None,
                 cache_object_min_size: Optional[pulumi.Input[int]] = None,
                 cache_size: Optional[pulumi.Input[int]] = None,
                 cache_uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_include_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_pinneds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProfileWebAcceleration resources.
        :param pulumi.Input[int] cache_aging_rate: Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        :param pulumi.Input[str] cache_client_cache_control_mode: Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        :param pulumi.Input[str] cache_insert_age_header: Inserts Age and Date headers in the response. The default value is `enabled`.
        :param pulumi.Input[int] cache_max_age: Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        :param pulumi.Input[int] cache_max_entries: Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        :param pulumi.Input[int] cache_object_max_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_object_min_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_size: Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_excludes: Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_include_overrides: Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_includes: Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_pinneds: Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] name: Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        """
        if cache_aging_rate is not None:
            pulumi.set(__self__, "cache_aging_rate", cache_aging_rate)
        if cache_client_cache_control_mode is not None:
            pulumi.set(__self__, "cache_client_cache_control_mode", cache_client_cache_control_mode)
        if cache_insert_age_header is not None:
            pulumi.set(__self__, "cache_insert_age_header", cache_insert_age_header)
        if cache_max_age is not None:
            pulumi.set(__self__, "cache_max_age", cache_max_age)
        if cache_max_entries is not None:
            pulumi.set(__self__, "cache_max_entries", cache_max_entries)
        if cache_object_max_size is not None:
            pulumi.set(__self__, "cache_object_max_size", cache_object_max_size)
        if cache_object_min_size is not None:
            pulumi.set(__self__, "cache_object_min_size", cache_object_min_size)
        if cache_size is not None:
            pulumi.set(__self__, "cache_size", cache_size)
        if cache_uri_excludes is not None:
            pulumi.set(__self__, "cache_uri_excludes", cache_uri_excludes)
        if cache_uri_include_overrides is not None:
            pulumi.set(__self__, "cache_uri_include_overrides", cache_uri_include_overrides)
        if cache_uri_includes is not None:
            pulumi.set(__self__, "cache_uri_includes", cache_uri_includes)
        if cache_uri_pinneds is not None:
            pulumi.set(__self__, "cache_uri_pinneds", cache_uri_pinneds)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="cacheAgingRate")
    def cache_aging_rate(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        """
        return pulumi.get(self, "cache_aging_rate")

    @cache_aging_rate.setter
    def cache_aging_rate(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_aging_rate", value)

    @property
    @pulumi.getter(name="cacheClientCacheControlMode")
    def cache_client_cache_control_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        """
        return pulumi.get(self, "cache_client_cache_control_mode")

    @cache_client_cache_control_mode.setter
    def cache_client_cache_control_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cache_client_cache_control_mode", value)

    @property
    @pulumi.getter(name="cacheInsertAgeHeader")
    def cache_insert_age_header(self) -> Optional[pulumi.Input[str]]:
        """
        Inserts Age and Date headers in the response. The default value is `enabled`.
        """
        return pulumi.get(self, "cache_insert_age_header")

    @cache_insert_age_header.setter
    def cache_insert_age_header(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cache_insert_age_header", value)

    @property
    @pulumi.getter(name="cacheMaxAge")
    def cache_max_age(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        """
        return pulumi.get(self, "cache_max_age")

    @cache_max_age.setter
    def cache_max_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_max_age", value)

    @property
    @pulumi.getter(name="cacheMaxEntries")
    def cache_max_entries(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        """
        return pulumi.get(self, "cache_max_entries")

    @cache_max_entries.setter
    def cache_max_entries(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_max_entries", value)

    @property
    @pulumi.getter(name="cacheObjectMaxSize")
    def cache_object_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        """
        return pulumi.get(self, "cache_object_max_size")

    @cache_object_max_size.setter
    def cache_object_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_object_max_size", value)

    @property
    @pulumi.getter(name="cacheObjectMinSize")
    def cache_object_min_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        """
        return pulumi.get(self, "cache_object_min_size")

    @cache_object_min_size.setter
    def cache_object_min_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_object_min_size", value)

    @property
    @pulumi.getter(name="cacheSize")
    def cache_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        """
        return pulumi.get(self, "cache_size")

    @cache_size.setter
    def cache_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cache_size", value)

    @property
    @pulumi.getter(name="cacheUriExcludes")
    def cache_uri_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        """
        return pulumi.get(self, "cache_uri_excludes")

    @cache_uri_excludes.setter
    def cache_uri_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_excludes", value)

    @property
    @pulumi.getter(name="cacheUriIncludeOverrides")
    def cache_uri_include_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        """
        return pulumi.get(self, "cache_uri_include_overrides")

    @cache_uri_include_overrides.setter
    def cache_uri_include_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_include_overrides", value)

    @property
    @pulumi.getter(name="cacheUriIncludes")
    def cache_uri_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        """
        return pulumi.get(self, "cache_uri_includes")

    @cache_uri_includes.setter
    def cache_uri_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_includes", value)

    @property
    @pulumi.getter(name="cacheUriPinneds")
    def cache_uri_pinneds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        """
        return pulumi.get(self, "cache_uri_pinneds")

    @cache_uri_pinneds.setter
    def cache_uri_pinneds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cache_uri_pinneds", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class ProfileWebAcceleration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cache_aging_rate: Optional[pulumi.Input[int]] = None,
                 cache_client_cache_control_mode: Optional[pulumi.Input[str]] = None,
                 cache_insert_age_header: Optional[pulumi.Input[str]] = None,
                 cache_max_age: Optional[pulumi.Input[int]] = None,
                 cache_max_entries: Optional[pulumi.Input[int]] = None,
                 cache_object_max_size: Optional[pulumi.Input[int]] = None,
                 cache_object_min_size: Optional[pulumi.Input[int]] = None,
                 cache_size: Optional[pulumi.Input[int]] = None,
                 cache_uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_include_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_pinneds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ltm.ProfileWebAcceleration` Configures a custom web-acceleration profile for use.

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/sample-resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        sample_resource = f5bigip.ltm.ProfileWebAcceleration("sample-resource",
            name="/Common/sample-resource",
            defaults_from="/Common/test2",
            cache_size=101,
            cache_max_entries=201)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] cache_aging_rate: Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        :param pulumi.Input[str] cache_client_cache_control_mode: Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        :param pulumi.Input[str] cache_insert_age_header: Inserts Age and Date headers in the response. The default value is `enabled`.
        :param pulumi.Input[int] cache_max_age: Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        :param pulumi.Input[int] cache_max_entries: Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        :param pulumi.Input[int] cache_object_max_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_object_min_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_size: Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_excludes: Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_include_overrides: Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_includes: Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_pinneds: Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] name: Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileWebAccelerationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileWebAcceleration` Configures a custom web-acceleration profile for use.

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/sample-resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        sample_resource = f5bigip.ltm.ProfileWebAcceleration("sample-resource",
            name="/Common/sample-resource",
            defaults_from="/Common/test2",
            cache_size=101,
            cache_max_entries=201)
        ```

        :param str resource_name: The name of the resource.
        :param ProfileWebAccelerationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileWebAccelerationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cache_aging_rate: Optional[pulumi.Input[int]] = None,
                 cache_client_cache_control_mode: Optional[pulumi.Input[str]] = None,
                 cache_insert_age_header: Optional[pulumi.Input[str]] = None,
                 cache_max_age: Optional[pulumi.Input[int]] = None,
                 cache_max_entries: Optional[pulumi.Input[int]] = None,
                 cache_object_max_size: Optional[pulumi.Input[int]] = None,
                 cache_object_min_size: Optional[pulumi.Input[int]] = None,
                 cache_size: Optional[pulumi.Input[int]] = None,
                 cache_uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_include_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_uri_pinneds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileWebAccelerationArgs.__new__(ProfileWebAccelerationArgs)

            __props__.__dict__["cache_aging_rate"] = cache_aging_rate
            __props__.__dict__["cache_client_cache_control_mode"] = cache_client_cache_control_mode
            __props__.__dict__["cache_insert_age_header"] = cache_insert_age_header
            __props__.__dict__["cache_max_age"] = cache_max_age
            __props__.__dict__["cache_max_entries"] = cache_max_entries
            __props__.__dict__["cache_object_max_size"] = cache_object_max_size
            __props__.__dict__["cache_object_min_size"] = cache_object_min_size
            __props__.__dict__["cache_size"] = cache_size
            __props__.__dict__["cache_uri_excludes"] = cache_uri_excludes
            __props__.__dict__["cache_uri_include_overrides"] = cache_uri_include_overrides
            __props__.__dict__["cache_uri_includes"] = cache_uri_includes
            __props__.__dict__["cache_uri_pinneds"] = cache_uri_pinneds
            __props__.__dict__["defaults_from"] = defaults_from
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
        super(ProfileWebAcceleration, __self__).__init__(
            'f5bigip:ltm/profileWebAcceleration:ProfileWebAcceleration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cache_aging_rate: Optional[pulumi.Input[int]] = None,
            cache_client_cache_control_mode: Optional[pulumi.Input[str]] = None,
            cache_insert_age_header: Optional[pulumi.Input[str]] = None,
            cache_max_age: Optional[pulumi.Input[int]] = None,
            cache_max_entries: Optional[pulumi.Input[int]] = None,
            cache_object_max_size: Optional[pulumi.Input[int]] = None,
            cache_object_min_size: Optional[pulumi.Input[int]] = None,
            cache_size: Optional[pulumi.Input[int]] = None,
            cache_uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            cache_uri_include_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            cache_uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            cache_uri_pinneds: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            defaults_from: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'ProfileWebAcceleration':
        """
        Get an existing ProfileWebAcceleration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] cache_aging_rate: Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        :param pulumi.Input[str] cache_client_cache_control_mode: Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        :param pulumi.Input[str] cache_insert_age_header: Inserts Age and Date headers in the response. The default value is `enabled`.
        :param pulumi.Input[int] cache_max_age: Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        :param pulumi.Input[int] cache_max_entries: Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        :param pulumi.Input[int] cache_object_max_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_object_min_size: Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        :param pulumi.Input[int] cache_size: Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_excludes: Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_include_overrides: Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_includes: Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cache_uri_pinneds: Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] name: Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileWebAccelerationState.__new__(_ProfileWebAccelerationState)

        __props__.__dict__["cache_aging_rate"] = cache_aging_rate
        __props__.__dict__["cache_client_cache_control_mode"] = cache_client_cache_control_mode
        __props__.__dict__["cache_insert_age_header"] = cache_insert_age_header
        __props__.__dict__["cache_max_age"] = cache_max_age
        __props__.__dict__["cache_max_entries"] = cache_max_entries
        __props__.__dict__["cache_object_max_size"] = cache_object_max_size
        __props__.__dict__["cache_object_min_size"] = cache_object_min_size
        __props__.__dict__["cache_size"] = cache_size
        __props__.__dict__["cache_uri_excludes"] = cache_uri_excludes
        __props__.__dict__["cache_uri_include_overrides"] = cache_uri_include_overrides
        __props__.__dict__["cache_uri_includes"] = cache_uri_includes
        __props__.__dict__["cache_uri_pinneds"] = cache_uri_pinneds
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["name"] = name
        return ProfileWebAcceleration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cacheAgingRate")
    def cache_aging_rate(self) -> pulumi.Output[int]:
        """
        Specifies how quickly the system ages a cache entry. The aging rate ranges from 0 (slowest aging) to 10 (fastest aging). The default value is `9`.
        """
        return pulumi.get(self, "cache_aging_rate")

    @property
    @pulumi.getter(name="cacheClientCacheControlMode")
    def cache_client_cache_control_mode(self) -> pulumi.Output[str]:
        """
        Specifies which cache disabling headers sent by clients the system ignores. The default value is `all`.
        """
        return pulumi.get(self, "cache_client_cache_control_mode")

    @property
    @pulumi.getter(name="cacheInsertAgeHeader")
    def cache_insert_age_header(self) -> pulumi.Output[str]:
        """
        Inserts Age and Date headers in the response. The default value is `enabled`.
        """
        return pulumi.get(self, "cache_insert_age_header")

    @property
    @pulumi.getter(name="cacheMaxAge")
    def cache_max_age(self) -> pulumi.Output[int]:
        """
        Specifies how long the system considers the cached content to be valid. The default value is `3600 seconds`.
        """
        return pulumi.get(self, "cache_max_age")

    @property
    @pulumi.getter(name="cacheMaxEntries")
    def cache_max_entries(self) -> pulumi.Output[int]:
        """
        Specifies the maximum number of entries that can be in the cache. The default value is `0` (zero), which means that the system does not limit the maximum entries.
        """
        return pulumi.get(self, "cache_max_entries")

    @property
    @pulumi.getter(name="cacheObjectMaxSize")
    def cache_object_max_size(self) -> pulumi.Output[int]:
        """
        Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        """
        return pulumi.get(self, "cache_object_max_size")

    @property
    @pulumi.getter(name="cacheObjectMinSize")
    def cache_object_min_size(self) -> pulumi.Output[int]:
        """
        Specifies the smallest object that the system considers eligible for caching. The default value is `500 bytes`.
        """
        return pulumi.get(self, "cache_object_min_size")

    @property
    @pulumi.getter(name="cacheSize")
    def cache_size(self) -> pulumi.Output[int]:
        """
        Specifies the maximum size for the cache. When the cache reaches the maximum size, the system starts removing the oldest entries. The default value is `100 megabytes`.
        """
        return pulumi.get(self, "cache_size")

    @property
    @pulumi.getter(name="cacheUriExcludes")
    def cache_uri_excludes(self) -> pulumi.Output[Sequence[str]]:
        """
        Configures a list of URIs to exclude from the cache. The default value of `none` specifies no URIs are excluded.
        """
        return pulumi.get(self, "cache_uri_excludes")

    @property
    @pulumi.getter(name="cacheUriIncludeOverrides")
    def cache_uri_include_overrides(self) -> pulumi.Output[Sequence[str]]:
        """
        Configures a list of URIs to include in the cache even if they would normally be excluded due to factors like object size or HTTP request type. The default value of none specifies no URIs are to be forced into the cache.
        """
        return pulumi.get(self, "cache_uri_include_overrides")

    @property
    @pulumi.getter(name="cacheUriIncludes")
    def cache_uri_includes(self) -> pulumi.Output[Sequence[str]]:
        """
        Configures a list of URIs to include in the cache. The default value of `.*` specifies that all URIs are cacheable.
        """
        return pulumi.get(self, "cache_uri_includes")

    @property
    @pulumi.getter(name="cacheUriPinneds")
    def cache_uri_pinneds(self) -> pulumi.Output[Sequence[str]]:
        """
        Configures a list of URIs to keep in the cache. The pinning process keeps URIs in cache when they would normally be evicted to make room for more active URIs.
        """
        return pulumi.get(self, "cache_uri_pinneds")

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[str]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the web acceleration profile service ,name of Profile should be full path. Full path is the combination of the `partition + web acceleration profile name`,For example `/Common/sample-resource`.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetWafPbSuggestionsResult',
    'AwaitableGetWafPbSuggestionsResult',
    'get_waf_pb_suggestions',
    'get_waf_pb_suggestions_output',
]

@pulumi.output_type
class GetWafPbSuggestionsResult:
    """
    A collection of values returned by getWafPbSuggestions.
    """
    def __init__(__self__, id=None, json=None, minimum_learning_score=None, partition=None, policy_id=None, policy_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if json and not isinstance(json, str):
            raise TypeError("Expected argument 'json' to be a str")
        pulumi.set(__self__, "json", json)
        if minimum_learning_score and not isinstance(minimum_learning_score, int):
            raise TypeError("Expected argument 'minimum_learning_score' to be a int")
        pulumi.set(__self__, "minimum_learning_score", minimum_learning_score)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)
        if policy_id and not isinstance(policy_id, str):
            raise TypeError("Expected argument 'policy_id' to be a str")
        pulumi.set(__self__, "policy_id", policy_id)
        if policy_name and not isinstance(policy_name, str):
            raise TypeError("Expected argument 'policy_name' to be a str")
        pulumi.set(__self__, "policy_name", policy_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def json(self) -> str:
        """
        Json string representing exported PB suggestions ready to be used in WAF policy declaration
        """
        return pulumi.get(self, "json")

    @property
    @pulumi.getter(name="minimumLearningScore")
    def minimum_learning_score(self) -> int:
        return pulumi.get(self, "minimum_learning_score")

    @property
    @pulumi.getter
    def partition(self) -> str:
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> str:
        """
        System generated id of the WAF policy
        """
        return pulumi.get(self, "policy_id")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> str:
        return pulumi.get(self, "policy_name")


class AwaitableGetWafPbSuggestionsResult(GetWafPbSuggestionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWafPbSuggestionsResult(
            id=self.id,
            json=self.json,
            minimum_learning_score=self.minimum_learning_score,
            partition=self.partition,
            policy_id=self.policy_id,
            policy_name=self.policy_name)


def get_waf_pb_suggestions(minimum_learning_score: Optional[int] = None,
                           partition: Optional[str] = None,
                           policy_id: Optional[str] = None,
                           policy_name: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWafPbSuggestionsResult:
    """
    Use this data source (`ssl_get_waf_pb_suggestions`) to export PB suggestions from an existing WAF policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    pbwaf1 = f5bigip.ssl.get_waf_pb_suggestions(policy_name="protect_me_policy",
        partition="Common",
        minimum_learning_score=20)
    ```


    :param int minimum_learning_score: The minimum learning score for suggestions.
    :param str partition: Partition on which WAF policy is located.
    :param str policy_id: System generated id of the WAF policy
    :param str policy_name: WAF policy name from which PB suggestions should be exported.
    """
    __args__ = dict()
    __args__['minimumLearningScore'] = minimum_learning_score
    __args__['partition'] = partition
    __args__['policyId'] = policy_id
    __args__['policyName'] = policy_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ssl/getWafPbSuggestions:getWafPbSuggestions', __args__, opts=opts, typ=GetWafPbSuggestionsResult).value

    return AwaitableGetWafPbSuggestionsResult(
        id=pulumi.get(__ret__, 'id'),
        json=pulumi.get(__ret__, 'json'),
        minimum_learning_score=pulumi.get(__ret__, 'minimum_learning_score'),
        partition=pulumi.get(__ret__, 'partition'),
        policy_id=pulumi.get(__ret__, 'policy_id'),
        policy_name=pulumi.get(__ret__, 'policy_name'))
def get_waf_pb_suggestions_output(minimum_learning_score: Optional[pulumi.Input[int]] = None,
                                  partition: Optional[pulumi.Input[str]] = None,
                                  policy_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  policy_name: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetWafPbSuggestionsResult]:
    """
    Use this data source (`ssl_get_waf_pb_suggestions`) to export PB suggestions from an existing WAF policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    pbwaf1 = f5bigip.ssl.get_waf_pb_suggestions(policy_name="protect_me_policy",
        partition="Common",
        minimum_learning_score=20)
    ```


    :param int minimum_learning_score: The minimum learning score for suggestions.
    :param str partition: Partition on which WAF policy is located.
    :param str policy_id: System generated id of the WAF policy
    :param str policy_name: WAF policy name from which PB suggestions should be exported.
    """
    __args__ = dict()
    __args__['minimumLearningScore'] = minimum_learning_score
    __args__['partition'] = partition
    __args__['policyId'] = policy_id
    __args__['policyName'] = policy_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ssl/getWafPbSuggestions:getWafPbSuggestions', __args__, opts=opts, typ=GetWafPbSuggestionsResult)
    return __ret__.apply(lambda __response__: GetWafPbSuggestionsResult(
        id=pulumi.get(__response__, 'id'),
        json=pulumi.get(__response__, 'json'),
        minimum_learning_score=pulumi.get(__response__, 'minimum_learning_score'),
        partition=pulumi.get(__response__, 'partition'),
        policy_id=pulumi.get(__response__, 'policy_id'),
        policy_name=pulumi.get(__response__, 'policy_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DnsArgs', 'Dns']

@pulumi.input_type
class DnsArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[str],
                 name_servers: pulumi.Input[Sequence[pulumi.Input[str]]],
                 number_of_dots: Optional[pulumi.Input[int]] = None,
                 searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Dns resource.
        :param pulumi.Input[str] description: Provide description for your DNS server
        :param pulumi.Input[Sequence[pulumi.Input[str]]] name_servers: Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        :param pulumi.Input[int] number_of_dots: Configures the number of dots needed in a name before an initial absolute query will be made.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] searches: Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "name_servers", name_servers)
        if number_of_dots is not None:
            pulumi.set(__self__, "number_of_dots", number_of_dots)
        if searches is not None:
            pulumi.set(__self__, "searches", searches)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        Provide description for your DNS server
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "name_servers", value)

    @property
    @pulumi.getter(name="numberOfDots")
    def number_of_dots(self) -> Optional[pulumi.Input[int]]:
        """
        Configures the number of dots needed in a name before an initial absolute query will be made.
        """
        return pulumi.get(self, "number_of_dots")

    @number_of_dots.setter
    def number_of_dots(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "number_of_dots", value)

    @property
    @pulumi.getter
    def searches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        return pulumi.get(self, "searches")

    @searches.setter
    def searches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "searches", value)


@pulumi.input_type
class _DnsState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 number_of_dots: Optional[pulumi.Input[int]] = None,
                 searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Dns resources.
        :param pulumi.Input[str] description: Provide description for your DNS server
        :param pulumi.Input[Sequence[pulumi.Input[str]]] name_servers: Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        :param pulumi.Input[int] number_of_dots: Configures the number of dots needed in a name before an initial absolute query will be made.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] searches: Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)
        if number_of_dots is not None:
            pulumi.set(__self__, "number_of_dots", number_of_dots)
        if searches is not None:
            pulumi.set(__self__, "searches", searches)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Provide description for your DNS server
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "name_servers", value)

    @property
    @pulumi.getter(name="numberOfDots")
    def number_of_dots(self) -> Optional[pulumi.Input[int]]:
        """
        Configures the number of dots needed in a name before an initial absolute query will be made.
        """
        return pulumi.get(self, "number_of_dots")

    @number_of_dots.setter
    def number_of_dots(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "number_of_dots", value)

    @property
    @pulumi.getter
    def searches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        return pulumi.get(self, "searches")

    @searches.setter
    def searches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "searches", value)


class Dns(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 number_of_dots: Optional[pulumi.Input[int]] = None,
                 searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        `sys.Dns` Configures DNS Name server on F5 BIG-IP

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        dns1 = f5bigip.sys.Dns("dns1",
            description="/Common/DNS1",
            name_servers=["1.1.1.1"],
            searches=["f5.com"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Provide description for your DNS server
        :param pulumi.Input[Sequence[pulumi.Input[str]]] name_servers: Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        :param pulumi.Input[int] number_of_dots: Configures the number of dots needed in a name before an initial absolute query will be made.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] searches: Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DnsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `sys.Dns` Configures DNS Name server on F5 BIG-IP

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        dns1 = f5bigip.sys.Dns("dns1",
            description="/Common/DNS1",
            name_servers=["1.1.1.1"],
            searches=["f5.com"])
        ```

        :param str resource_name: The name of the resource.
        :param DnsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DnsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 number_of_dots: Optional[pulumi.Input[int]] = None,
                 searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DnsArgs.__new__(DnsArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if name_servers is None and not opts.urn:
                raise TypeError("Missing required property 'name_servers'")
            __props__.__dict__["name_servers"] = name_servers
            __props__.__dict__["number_of_dots"] = number_of_dots
            __props__.__dict__["searches"] = searches
        super(Dns, __self__).__init__(
            'f5bigip:sys/dns:Dns',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            number_of_dots: Optional[pulumi.Input[int]] = None,
            searches: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Dns':
        """
        Get an existing Dns resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Provide description for your DNS server
        :param pulumi.Input[Sequence[pulumi.Input[str]]] name_servers: Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        :param pulumi.Input[int] number_of_dots: Configures the number of dots needed in a name before an initial absolute query will be made.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] searches: Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DnsState.__new__(_DnsState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name_servers"] = name_servers
        __props__.__dict__["number_of_dots"] = number_of_dots
        __props__.__dict__["searches"] = searches
        return Dns(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Provide description for your DNS server
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> pulumi.Output[Sequence[str]]:
        """
        Specifies the name servers that the system uses to validate DNS lookups, and resolve host names.
        """
        return pulumi.get(self, "name_servers")

    @property
    @pulumi.getter(name="numberOfDots")
    def number_of_dots(self) -> pulumi.Output[int]:
        """
        Configures the number of dots needed in a name before an initial absolute query will be made.
        """
        return pulumi.get(self, "number_of_dots")

    @property
    @pulumi.getter
    def searches(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Specifies the domains that the system searches for local domain lookups, to resolve local host names.
        """
        return pulumi.get(self, "searches")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPoolResult',
    'AwaitableGetPoolResult',
    'get_pool',
    'get_pool_output',
]

@pulumi.output_type
class GetPoolResult:
    """
    A collection of values returned by getPool.
    """
    def __init__(__self__, full_path=None, id=None, name=None, partition=None):
        if full_path and not isinstance(full_path, str):
            raise TypeError("Expected argument 'full_path' to be a str")
        pulumi.set(__self__, "full_path", full_path)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> str:
        """
        Full path to the pool.
        """
        return pulumi.get(self, "full_path")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> str:
        return pulumi.get(self, "partition")


class AwaitableGetPoolResult(GetPoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPoolResult(
            full_path=self.full_path,
            id=self.id,
            name=self.name,
            partition=self.partition)


def get_pool(name: Optional[str] = None,
             partition: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPoolResult:
    """
    Use this data source (`ltm.Pool`) to get the ltm monitor details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    pool__example = f5bigip.ltm.get_pool(name="example-pool",
        partition="Common")
    ```


    :param str name: Name of the ltm monitor
    :param str partition: partition of the ltm monitor
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ltm/getPool:getPool', __args__, opts=opts, typ=GetPoolResult).value

    return AwaitableGetPoolResult(
        full_path=pulumi.get(__ret__, 'full_path'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        partition=pulumi.get(__ret__, 'partition'))
def get_pool_output(name: Optional[pulumi.Input[str]] = None,
                    partition: Optional[pulumi.Input[str]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPoolResult]:
    """
    Use this data source (`ltm.Pool`) to get the ltm monitor details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    pool__example = f5bigip.ltm.get_pool(name="example-pool",
        partition="Common")
    ```


    :param str name: Name of the ltm monitor
    :param str partition: partition of the ltm monitor
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ltm/getPool:getPool', __args__, opts=opts, typ=GetPoolResult)
    return __ret__.apply(lambda __response__: GetPoolResult(
        full_path=pulumi.get(__response__, 'full_path'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        partition=pulumi.get(__response__, 'partition')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NodeArgs', 'Node']

@pulumi.input_type
class NodeArgs:
    def __init__(__self__, *,
                 address: pulumi.Input[str],
                 name: pulumi.Input[str],
                 connection_limit: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_ratio: Optional[pulumi.Input[int]] = None,
                 fqdn: Optional[pulumi.Input['NodeFqdnArgs']] = None,
                 monitor: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input[str]] = None,
                 ratio: Optional[pulumi.Input[int]] = None,
                 session: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Node resource.
        :param pulumi.Input[str] address: IP or hostname of the node
        :param pulumi.Input[str] name: Name of the node
        :param pulumi.Input[int] connection_limit: Specifies the maximum number of connections allowed for the node or node address.
        :param pulumi.Input[str] description: User-defined description give ltm_node
        :param pulumi.Input[int] dynamic_ratio: Specifies the fixed ratio value used for a node during ratio load balancing.
        :param pulumi.Input[str] monitor: specifies the name of the monitor or monitor rule that you want to associate with the node.
        :param pulumi.Input[str] rate_limit: Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        :param pulumi.Input[int] ratio: Sets the ratio number for the node.
        :param pulumi.Input[str] session: Enables or disables the node for new sessions. The default value is user-enabled.
        :param pulumi.Input[str] state: Default is "user-up" you can set to "user-down" if you want to disable
               
               > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "name", name)
        if connection_limit is not None:
            pulumi.set(__self__, "connection_limit", connection_limit)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dynamic_ratio is not None:
            pulumi.set(__self__, "dynamic_ratio", dynamic_ratio)
        if fqdn is not None:
            pulumi.set(__self__, "fqdn", fqdn)
        if monitor is not None:
            pulumi.set(__self__, "monitor", monitor)
        if rate_limit is not None:
            pulumi.set(__self__, "rate_limit", rate_limit)
        if ratio is not None:
            pulumi.set(__self__, "ratio", ratio)
        if session is not None:
            pulumi.set(__self__, "session", session)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Input[str]:
        """
        IP or hostname of the node
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: pulumi.Input[str]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the node
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of connections allowed for the node or node address.
        """
        return pulumi.get(self, "connection_limit")

    @connection_limit.setter
    def connection_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "connection_limit", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        User-defined description give ltm_node
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dynamicRatio")
    def dynamic_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the fixed ratio value used for a node during ratio load balancing.
        """
        return pulumi.get(self, "dynamic_ratio")

    @dynamic_ratio.setter
    def dynamic_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "dynamic_ratio", value)

    @property
    @pulumi.getter
    def fqdn(self) -> Optional[pulumi.Input['NodeFqdnArgs']]:
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: Optional[pulumi.Input['NodeFqdnArgs']]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter
    def monitor(self) -> Optional[pulumi.Input[str]]:
        """
        specifies the name of the monitor or monitor rule that you want to associate with the node.
        """
        return pulumi.get(self, "monitor")

    @monitor.setter
    def monitor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor", value)

    @property
    @pulumi.getter(name="rateLimit")
    def rate_limit(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        """
        return pulumi.get(self, "rate_limit")

    @rate_limit.setter
    def rate_limit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rate_limit", value)

    @property
    @pulumi.getter
    def ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Sets the ratio number for the node.
        """
        return pulumi.get(self, "ratio")

    @ratio.setter
    def ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ratio", value)

    @property
    @pulumi.getter
    def session(self) -> Optional[pulumi.Input[str]]:
        """
        Enables or disables the node for new sessions. The default value is user-enabled.
        """
        return pulumi.get(self, "session")

    @session.setter
    def session(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Default is "user-up" you can set to "user-down" if you want to disable

        > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class _NodeState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[str]] = None,
                 connection_limit: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_ratio: Optional[pulumi.Input[int]] = None,
                 fqdn: Optional[pulumi.Input['NodeFqdnArgs']] = None,
                 monitor: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input[str]] = None,
                 ratio: Optional[pulumi.Input[int]] = None,
                 session: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Node resources.
        :param pulumi.Input[str] address: IP or hostname of the node
        :param pulumi.Input[int] connection_limit: Specifies the maximum number of connections allowed for the node or node address.
        :param pulumi.Input[str] description: User-defined description give ltm_node
        :param pulumi.Input[int] dynamic_ratio: Specifies the fixed ratio value used for a node during ratio load balancing.
        :param pulumi.Input[str] monitor: specifies the name of the monitor or monitor rule that you want to associate with the node.
        :param pulumi.Input[str] name: Name of the node
        :param pulumi.Input[str] rate_limit: Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        :param pulumi.Input[int] ratio: Sets the ratio number for the node.
        :param pulumi.Input[str] session: Enables or disables the node for new sessions. The default value is user-enabled.
        :param pulumi.Input[str] state: Default is "user-up" you can set to "user-down" if you want to disable
               
               > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if connection_limit is not None:
            pulumi.set(__self__, "connection_limit", connection_limit)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dynamic_ratio is not None:
            pulumi.set(__self__, "dynamic_ratio", dynamic_ratio)
        if fqdn is not None:
            pulumi.set(__self__, "fqdn", fqdn)
        if monitor is not None:
            pulumi.set(__self__, "monitor", monitor)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rate_limit is not None:
            pulumi.set(__self__, "rate_limit", rate_limit)
        if ratio is not None:
            pulumi.set(__self__, "ratio", ratio)
        if session is not None:
            pulumi.set(__self__, "session", session)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[str]]:
        """
        IP or hostname of the node
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of connections allowed for the node or node address.
        """
        return pulumi.get(self, "connection_limit")

    @connection_limit.setter
    def connection_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "connection_limit", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        User-defined description give ltm_node
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dynamicRatio")
    def dynamic_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the fixed ratio value used for a node during ratio load balancing.
        """
        return pulumi.get(self, "dynamic_ratio")

    @dynamic_ratio.setter
    def dynamic_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "dynamic_ratio", value)

    @property
    @pulumi.getter
    def fqdn(self) -> Optional[pulumi.Input['NodeFqdnArgs']]:
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: Optional[pulumi.Input['NodeFqdnArgs']]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter
    def monitor(self) -> Optional[pulumi.Input[str]]:
        """
        specifies the name of the monitor or monitor rule that you want to associate with the node.
        """
        return pulumi.get(self, "monitor")

    @monitor.setter
    def monitor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the node
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="rateLimit")
    def rate_limit(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        """
        return pulumi.get(self, "rate_limit")

    @rate_limit.setter
    def rate_limit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rate_limit", value)

    @property
    @pulumi.getter
    def ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Sets the ratio number for the node.
        """
        return pulumi.get(self, "ratio")

    @ratio.setter
    def ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ratio", value)

    @property
    @pulumi.getter
    def session(self) -> Optional[pulumi.Input[str]]:
        """
        Enables or disables the node for new sessions. The default value is user-enabled.
        """
        return pulumi.get(self, "session")

    @session.setter
    def session(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Default is "user-up" you can set to "user-down" if you want to disable

        > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


class Node(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[str]] = None,
                 connection_limit: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_ratio: Optional[pulumi.Input[int]] = None,
                 fqdn: Optional[pulumi.Input[Union['NodeFqdnArgs', 'NodeFqdnArgsDict']]] = None,
                 monitor: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input[str]] = None,
                 ratio: Optional[pulumi.Input[int]] = None,
                 session: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ltm.Node` Manages a node configuration

        For resources should be named with their `full path`.The full path is the combination of the `partition + name` of the resource( example: `/Common/my-node` ) or `partition + Direcroty + name` of the resource ( example: `/Common/test/my-node` ).
        When including directory in `full path` we have to make sure it is created in the given partition before using it.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        node = f5bigip.ltm.Node("node",
            name="/Common/terraform_node1",
            address="192.168.30.1",
            connection_limit=0,
            dynamic_ratio=1,
            monitor="/Common/icmp",
            description="Test-Node",
            rate_limit="disabled",
            fqdn={
                "address_family": "ipv4",
                "interval": "3000",
            })
        ```

        ## Importing

        An existing Node can be imported into this resource by supplying Node Name in `full path` as `id`.
        An example is below:
        ```sh
        $ terraform import bigip_ltm_node.site2_node "/TEST/testnode"
                    (or)
        $ terraform import bigip_ltm_node.site2_node "/Common/3.3.3.3"

        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: IP or hostname of the node
        :param pulumi.Input[int] connection_limit: Specifies the maximum number of connections allowed for the node or node address.
        :param pulumi.Input[str] description: User-defined description give ltm_node
        :param pulumi.Input[int] dynamic_ratio: Specifies the fixed ratio value used for a node during ratio load balancing.
        :param pulumi.Input[str] monitor: specifies the name of the monitor or monitor rule that you want to associate with the node.
        :param pulumi.Input[str] name: Name of the node
        :param pulumi.Input[str] rate_limit: Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        :param pulumi.Input[int] ratio: Sets the ratio number for the node.
        :param pulumi.Input[str] session: Enables or disables the node for new sessions. The default value is user-enabled.
        :param pulumi.Input[str] state: Default is "user-up" you can set to "user-down" if you want to disable
               
               > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NodeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.Node` Manages a node configuration

        For resources should be named with their `full path`.The full path is the combination of the `partition + name` of the resource( example: `/Common/my-node` ) or `partition + Direcroty + name` of the resource ( example: `/Common/test/my-node` ).
        When including directory in `full path` we have to make sure it is created in the given partition before using it.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        node = f5bigip.ltm.Node("node",
            name="/Common/terraform_node1",
            address="192.168.30.1",
            connection_limit=0,
            dynamic_ratio=1,
            monitor="/Common/icmp",
            description="Test-Node",
            rate_limit="disabled",
            fqdn={
                "address_family": "ipv4",
                "interval": "3000",
            })
        ```

        ## Importing

        An existing Node can be imported into this resource by supplying Node Name in `full path` as `id`.
        An example is below:
        ```sh
        $ terraform import bigip_ltm_node.site2_node "/TEST/testnode"
                    (or)
        $ terraform import bigip_ltm_node.site2_node "/Common/3.3.3.3"

        ```

        :param str resource_name: The name of the resource.
        :param NodeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NodeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[str]] = None,
                 connection_limit: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_ratio: Optional[pulumi.Input[int]] = None,
                 fqdn: Optional[pulumi.Input[Union['NodeFqdnArgs', 'NodeFqdnArgsDict']]] = None,
                 monitor: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input[str]] = None,
                 ratio: Optional[pulumi.Input[int]] = None,
                 session: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NodeArgs.__new__(NodeArgs)

            if address is None and not opts.urn:
                raise TypeError("Missing required property 'address'")
            __props__.__dict__["address"] = address
            __props__.__dict__["connection_limit"] = connection_limit
            __props__.__dict__["description"] = description
            __props__.__dict__["dynamic_ratio"] = dynamic_ratio
            __props__.__dict__["fqdn"] = fqdn
            __props__.__dict__["monitor"] = monitor
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["rate_limit"] = rate_limit
            __props__.__dict__["ratio"] = ratio
            __props__.__dict__["session"] = session
            __props__.__dict__["state"] = state
        super(Node, __self__).__init__(
            'f5bigip:ltm/node:Node',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[str]] = None,
            connection_limit: Optional[pulumi.Input[int]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dynamic_ratio: Optional[pulumi.Input[int]] = None,
            fqdn: Optional[pulumi.Input[Union['NodeFqdnArgs', 'NodeFqdnArgsDict']]] = None,
            monitor: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            rate_limit: Optional[pulumi.Input[str]] = None,
            ratio: Optional[pulumi.Input[int]] = None,
            session: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None) -> 'Node':
        """
        Get an existing Node resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: IP or hostname of the node
        :param pulumi.Input[int] connection_limit: Specifies the maximum number of connections allowed for the node or node address.
        :param pulumi.Input[str] description: User-defined description give ltm_node
        :param pulumi.Input[int] dynamic_ratio: Specifies the fixed ratio value used for a node during ratio load balancing.
        :param pulumi.Input[str] monitor: specifies the name of the monitor or monitor rule that you want to associate with the node.
        :param pulumi.Input[str] name: Name of the node
        :param pulumi.Input[str] rate_limit: Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        :param pulumi.Input[int] ratio: Sets the ratio number for the node.
        :param pulumi.Input[str] session: Enables or disables the node for new sessions. The default value is user-enabled.
        :param pulumi.Input[str] state: Default is "user-up" you can set to "user-down" if you want to disable
               
               > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NodeState.__new__(_NodeState)

        __props__.__dict__["address"] = address
        __props__.__dict__["connection_limit"] = connection_limit
        __props__.__dict__["description"] = description
        __props__.__dict__["dynamic_ratio"] = dynamic_ratio
        __props__.__dict__["fqdn"] = fqdn
        __props__.__dict__["monitor"] = monitor
        __props__.__dict__["name"] = name
        __props__.__dict__["rate_limit"] = rate_limit
        __props__.__dict__["ratio"] = ratio
        __props__.__dict__["session"] = session
        __props__.__dict__["state"] = state
        return Node(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Output[str]:
        """
        IP or hostname of the node
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> pulumi.Output[int]:
        """
        Specifies the maximum number of connections allowed for the node or node address.
        """
        return pulumi.get(self, "connection_limit")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        User-defined description give ltm_node
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dynamicRatio")
    def dynamic_ratio(self) -> pulumi.Output[int]:
        """
        Specifies the fixed ratio value used for a node during ratio load balancing.
        """
        return pulumi.get(self, "dynamic_ratio")

    @property
    @pulumi.getter
    def fqdn(self) -> pulumi.Output[Optional['outputs.NodeFqdn']]:
        return pulumi.get(self, "fqdn")

    @property
    @pulumi.getter
    def monitor(self) -> pulumi.Output[Optional[str]]:
        """
        specifies the name of the monitor or monitor rule that you want to associate with the node.
        """
        return pulumi.get(self, "monitor")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the node
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="rateLimit")
    def rate_limit(self) -> pulumi.Output[str]:
        """
        Specifies the maximum number of connections per second allowed for a node or node address. The default value is 'disabled'.
        """
        return pulumi.get(self, "rate_limit")

    @property
    @pulumi.getter
    def ratio(self) -> pulumi.Output[int]:
        """
        Sets the ratio number for the node.
        """
        return pulumi.get(self, "ratio")

    @property
    @pulumi.getter
    def session(self) -> pulumi.Output[str]:
        """
        Enables or disables the node for new sessions. The default value is user-enabled.
        """
        return pulumi.get(self, "session")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        Default is "user-up" you can set to "user-down" if you want to disable

        > *NOTE* Below attributes needs to be configured under fqdn option.
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetMonitorResult',
    'AwaitableGetMonitorResult',
    'get_monitor',
    'get_monitor_output',
]

@pulumi.output_type
class GetMonitorResult:
    """
    A collection of values returned by getMonitor.
    """
    def __init__(__self__, adaptive=None, adaptive_limit=None, base=None, chase_referrals=None, database=None, defaults_from=None, destination=None, filename=None, filter=None, id=None, interval=None, ip_dscp=None, mandatory_attributes=None, manual_resume=None, mode=None, name=None, partition=None, receive_disable=None, reverse=None, security=None, time_until_up=None, timeout=None, transparent=None, username=None):
        if adaptive and not isinstance(adaptive, str):
            raise TypeError("Expected argument 'adaptive' to be a str")
        pulumi.set(__self__, "adaptive", adaptive)
        if adaptive_limit and not isinstance(adaptive_limit, int):
            raise TypeError("Expected argument 'adaptive_limit' to be a int")
        pulumi.set(__self__, "adaptive_limit", adaptive_limit)
        if base and not isinstance(base, str):
            raise TypeError("Expected argument 'base' to be a str")
        pulumi.set(__self__, "base", base)
        if chase_referrals and not isinstance(chase_referrals, str):
            raise TypeError("Expected argument 'chase_referrals' to be a str")
        pulumi.set(__self__, "chase_referrals", chase_referrals)
        if database and not isinstance(database, str):
            raise TypeError("Expected argument 'database' to be a str")
        pulumi.set(__self__, "database", database)
        if defaults_from and not isinstance(defaults_from, str):
            raise TypeError("Expected argument 'defaults_from' to be a str")
        pulumi.set(__self__, "defaults_from", defaults_from)
        if destination and not isinstance(destination, str):
            raise TypeError("Expected argument 'destination' to be a str")
        pulumi.set(__self__, "destination", destination)
        if filename and not isinstance(filename, str):
            raise TypeError("Expected argument 'filename' to be a str")
        pulumi.set(__self__, "filename", filename)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if interval and not isinstance(interval, int):
            raise TypeError("Expected argument 'interval' to be a int")
        pulumi.set(__self__, "interval", interval)
        if ip_dscp and not isinstance(ip_dscp, int):
            raise TypeError("Expected argument 'ip_dscp' to be a int")
        pulumi.set(__self__, "ip_dscp", ip_dscp)
        if mandatory_attributes and not isinstance(mandatory_attributes, str):
            raise TypeError("Expected argument 'mandatory_attributes' to be a str")
        pulumi.set(__self__, "mandatory_attributes", mandatory_attributes)
        if manual_resume and not isinstance(manual_resume, str):
            raise TypeError("Expected argument 'manual_resume' to be a str")
        pulumi.set(__self__, "manual_resume", manual_resume)
        if mode and not isinstance(mode, str):
            raise TypeError("Expected argument 'mode' to be a str")
        pulumi.set(__self__, "mode", mode)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)
        if receive_disable and not isinstance(receive_disable, str):
            raise TypeError("Expected argument 'receive_disable' to be a str")
        pulumi.set(__self__, "receive_disable", receive_disable)
        if reverse and not isinstance(reverse, str):
            raise TypeError("Expected argument 'reverse' to be a str")
        pulumi.set(__self__, "reverse", reverse)
        if security and not isinstance(security, str):
            raise TypeError("Expected argument 'security' to be a str")
        pulumi.set(__self__, "security", security)
        if time_until_up and not isinstance(time_until_up, int):
            raise TypeError("Expected argument 'time_until_up' to be a int")
        pulumi.set(__self__, "time_until_up", time_until_up)
        if timeout and not isinstance(timeout, int):
            raise TypeError("Expected argument 'timeout' to be a int")
        pulumi.set(__self__, "timeout", timeout)
        if transparent and not isinstance(transparent, str):
            raise TypeError("Expected argument 'transparent' to be a str")
        pulumi.set(__self__, "transparent", transparent)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def adaptive(self) -> str:
        """
        Displays whether adaptive response time monitoring is enabled for this monitor.
        """
        return pulumi.get(self, "adaptive")

    @property
    @pulumi.getter(name="adaptiveLimit")
    def adaptive_limit(self) -> int:
        """
        Displays whether adaptive response time monitoring is enabled for this monitor.
        """
        return pulumi.get(self, "adaptive_limit")

    @property
    @pulumi.getter
    def base(self) -> str:
        return pulumi.get(self, "base")

    @property
    @pulumi.getter(name="chaseReferrals")
    def chase_referrals(self) -> str:
        return pulumi.get(self, "chase_referrals")

    @property
    @pulumi.getter
    def database(self) -> str:
        return pulumi.get(self, "database")

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> str:
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter
    def destination(self) -> str:
        """
        id will be full path name of ltm monitor.
        """
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter
    def filename(self) -> str:
        return pulumi.get(self, "filename")

    @property
    @pulumi.getter
    def filter(self) -> str:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def interval(self) -> int:
        """
        Specifies, in seconds, the frequency at which the system issues the monitor check when either the resource is down or the status of the resource is unknown.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="ipDscp")
    def ip_dscp(self) -> int:
        """
        Displays the differentiated services code point (DSCP). DSCP is a 6-bit value in the Differentiated Services (DS) field of the IP header.
        """
        return pulumi.get(self, "ip_dscp")

    @property
    @pulumi.getter(name="mandatoryAttributes")
    def mandatory_attributes(self) -> str:
        return pulumi.get(self, "mandatory_attributes")

    @property
    @pulumi.getter(name="manualResume")
    def manual_resume(self) -> str:
        """
        Displays whether the system automatically changes the status of a resource to Enabled at the next successful monitor check.
        """
        return pulumi.get(self, "manual_resume")

    @property
    @pulumi.getter
    def mode(self) -> str:
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> str:
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="receiveDisable")
    def receive_disable(self) -> str:
        return pulumi.get(self, "receive_disable")

    @property
    @pulumi.getter
    def reverse(self) -> str:
        """
        Instructs the system to mark the target resource down when the test is successful.
        """
        return pulumi.get(self, "reverse")

    @property
    @pulumi.getter
    def security(self) -> str:
        return pulumi.get(self, "security")

    @property
    @pulumi.getter(name="timeUntilUp")
    def time_until_up(self) -> int:
        return pulumi.get(self, "time_until_up")

    @property
    @pulumi.getter
    def timeout(self) -> int:
        return pulumi.get(self, "timeout")

    @property
    @pulumi.getter
    def transparent(self) -> str:
        """
        Displays whether the monitor operates in transparent mode.
        """
        return pulumi.get(self, "transparent")

    @property
    @pulumi.getter
    def username(self) -> str:
        return pulumi.get(self, "username")


class AwaitableGetMonitorResult(GetMonitorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMonitorResult(
            adaptive=self.adaptive,
            adaptive_limit=self.adaptive_limit,
            base=self.base,
            chase_referrals=self.chase_referrals,
            database=self.database,
            defaults_from=self.defaults_from,
            destination=self.destination,
            filename=self.filename,
            filter=self.filter,
            id=self.id,
            interval=self.interval,
            ip_dscp=self.ip_dscp,
            mandatory_attributes=self.mandatory_attributes,
            manual_resume=self.manual_resume,
            mode=self.mode,
            name=self.name,
            partition=self.partition,
            receive_disable=self.receive_disable,
            reverse=self.reverse,
            security=self.security,
            time_until_up=self.time_until_up,
            timeout=self.timeout,
            transparent=self.transparent,
            username=self.username)


def get_monitor(name: Optional[str] = None,
                partition: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMonitorResult:
    """
    Use this data source (`ltm.Monitor`) to get the ltm monitor details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    monitor__tc1 = f5bigip.ltm.get_monitor(name="test-monitor",
        partition="Common")
    ```


    :param str name: Name of the ltm monitor
    :param str partition: partition of the ltm monitor
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ltm/getMonitor:getMonitor', __args__, opts=opts, typ=GetMonitorResult).value

    return AwaitableGetMonitorResult(
        adaptive=pulumi.get(__ret__, 'adaptive'),
        adaptive_limit=pulumi.get(__ret__, 'adaptive_limit'),
        base=pulumi.get(__ret__, 'base'),
        chase_referrals=pulumi.get(__ret__, 'chase_referrals'),
        database=pulumi.get(__ret__, 'database'),
        defaults_from=pulumi.get(__ret__, 'defaults_from'),
        destination=pulumi.get(__ret__, 'destination'),
        filename=pulumi.get(__ret__, 'filename'),
        filter=pulumi.get(__ret__, 'filter'),
        id=pulumi.get(__ret__, 'id'),
        interval=pulumi.get(__ret__, 'interval'),
        ip_dscp=pulumi.get(__ret__, 'ip_dscp'),
        mandatory_attributes=pulumi.get(__ret__, 'mandatory_attributes'),
        manual_resume=pulumi.get(__ret__, 'manual_resume'),
        mode=pulumi.get(__ret__, 'mode'),
        name=pulumi.get(__ret__, 'name'),
        partition=pulumi.get(__ret__, 'partition'),
        receive_disable=pulumi.get(__ret__, 'receive_disable'),
        reverse=pulumi.get(__ret__, 'reverse'),
        security=pulumi.get(__ret__, 'security'),
        time_until_up=pulumi.get(__ret__, 'time_until_up'),
        timeout=pulumi.get(__ret__, 'timeout'),
        transparent=pulumi.get(__ret__, 'transparent'),
        username=pulumi.get(__ret__, 'username'))
def get_monitor_output(name: Optional[pulumi.Input[str]] = None,
                       partition: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMonitorResult]:
    """
    Use this data source (`ltm.Monitor`) to get the ltm monitor details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    monitor__tc1 = f5bigip.ltm.get_monitor(name="test-monitor",
        partition="Common")
    ```


    :param str name: Name of the ltm monitor
    :param str partition: partition of the ltm monitor
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ltm/getMonitor:getMonitor', __args__, opts=opts, typ=GetMonitorResult)
    return __ret__.apply(lambda __response__: GetMonitorResult(
        adaptive=pulumi.get(__response__, 'adaptive'),
        adaptive_limit=pulumi.get(__response__, 'adaptive_limit'),
        base=pulumi.get(__response__, 'base'),
        chase_referrals=pulumi.get(__response__, 'chase_referrals'),
        database=pulumi.get(__response__, 'database'),
        defaults_from=pulumi.get(__response__, 'defaults_from'),
        destination=pulumi.get(__response__, 'destination'),
        filename=pulumi.get(__response__, 'filename'),
        filter=pulumi.get(__response__, 'filter'),
        id=pulumi.get(__response__, 'id'),
        interval=pulumi.get(__response__, 'interval'),
        ip_dscp=pulumi.get(__response__, 'ip_dscp'),
        mandatory_attributes=pulumi.get(__response__, 'mandatory_attributes'),
        manual_resume=pulumi.get(__response__, 'manual_resume'),
        mode=pulumi.get(__response__, 'mode'),
        name=pulumi.get(__response__, 'name'),
        partition=pulumi.get(__response__, 'partition'),
        receive_disable=pulumi.get(__response__, 'receive_disable'),
        reverse=pulumi.get(__response__, 'reverse'),
        security=pulumi.get(__response__, 'security'),
        time_until_up=pulumi.get(__response__, 'time_until_up'),
        timeout=pulumi.get(__response__, 'timeout'),
        transparent=pulumi.get(__response__, 'transparent'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'IAppList',
    'IAppMetadata',
    'IAppTable',
    'IAppTableRow',
    'IAppVariable',
]

@pulumi.output_type
class IAppList(dict):
    def __init__(__self__, *,
                 encrypted: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str encrypted: Name of origin
        :param str value: Name of origin
        """
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "encrypted")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class IAppMetadata(dict):
    def __init__(__self__, *,
                 persists: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str persists: Name of origin
        :param str value: Name of origin
        """
        if persists is not None:
            pulumi.set(__self__, "persists", persists)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def persists(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "persists")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class IAppTable(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "columnNames":
            suggest = "column_names"
        elif key == "encryptedColumns":
            suggest = "encrypted_columns"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in IAppTable. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        IAppTable.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        IAppTable.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 column_names: Optional[Sequence[str]] = None,
                 encrypted_columns: Optional[str] = None,
                 name: Optional[str] = None,
                 rows: Optional[Sequence['outputs.IAppTableRow']] = None):
        """
        :param str encrypted_columns: Name of origin
        :param str name: Name of the iApp.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if encrypted_columns is not None:
            pulumi.set(__self__, "encrypted_columns", encrypted_columns)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rows is not None:
            pulumi.set(__self__, "rows", rows)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "column_names")

    @property
    @pulumi.getter(name="encryptedColumns")
    def encrypted_columns(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "encrypted_columns")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def rows(self) -> Optional[Sequence['outputs.IAppTableRow']]:
        return pulumi.get(self, "rows")


@pulumi.output_type
class IAppTableRow(dict):
    def __init__(__self__, *,
                 rows: Optional[Sequence[str]] = None):
        if rows is not None:
            pulumi.set(__self__, "rows", rows)

    @property
    @pulumi.getter
    def rows(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "rows")


@pulumi.output_type
class IAppVariable(dict):
    def __init__(__self__, *,
                 encrypted: Optional[str] = None,
                 name: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str encrypted: Name of origin
        :param str name: Name of the iApp.
        :param str value: Name of origin
        """
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "encrypted")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        Name of origin
        """
        return pulumi.get(self, "value")


